==> docker-model-1.2.0-sources.jar: annotations/io/fabric8/docker/api/model/NetworkSettingsFluent.java <==
package io.fabric8.docker.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.docker.api.builder.Nested;
import java.lang.String;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.sundr.builder.annotations.Buildable;
import javax.annotation.Generated;
import io.fabric8.docker.api.builder.Fluent;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.Valid;
import java.lang.Object;
import lombok.ToString;
import java.util.Map;

public interface NetworkSettingsFluent<A extends NetworkSettingsFluent<A>> extends Fluent<A>{


    public DefaultNetworkSettings getDefaultNetworkSettings();
    public A withDefaultNetworkSettings(DefaultNetworkSettings DefaultNetworkSettings);
    public NetworkSettingsFluent.DefaultNetworkSettingsNested<A> withNewDefaultNetworkSettings();
    public NetworkSettingsFluent.DefaultNetworkSettingsNested<A> withNewDefaultNetworkSettingsLike(DefaultNetworkSettings item);
    public NetworkSettingsFluent.DefaultNetworkSettingsNested<A> editDefaultNetworkSettings();
    public NetworkSettingsFluent.DefaultNetworkSettingsNested<A> editOrNewDefaultNetworkSettings();
    public NetworkSettingsFluent.DefaultNetworkSettingsNested<A> editOrNewDefaultNetworkSettingsLike(DefaultNetworkSettings item);
    public NetworkSettingsBase getNetworkSettingsBase();
    public A withNetworkSettingsBase(NetworkSettingsBase NetworkSettingsBase);
    public NetworkSettingsFluent.NetworkSettingsBaseNested<A> withNewNetworkSettingsBase();
    public NetworkSettingsFluent.NetworkSettingsBaseNested<A> withNewNetworkSettingsBaseLike(NetworkSettingsBase item);
    public NetworkSettingsFluent.NetworkSettingsBaseNested<A> editNetworkSettingsBase();
    public NetworkSettingsFluent.NetworkSettingsBaseNested<A> editOrNewNetworkSettingsBase();
    public NetworkSettingsFluent.NetworkSettingsBaseNested<A> editOrNewNetworkSettingsBaseLike(NetworkSettingsBase item);
    public A addToNetworks(String key,EndpointSettings value);
    public A addToNetworks(Map<String,EndpointSettings> map);
    public A removeFromNetworks(String key);
    public A removeFromNetworks(Map<String,EndpointSettings> map);
    public Map<String,EndpointSettings> getNetworks();
    public A withNetworks(Map<String,EndpointSettings> Networks);

    public interface DefaultNetworkSettingsNested<N> extends io.fabric8.docker.api.builder.Nested<N>,DefaultNetworkSettingsFluent<NetworkSettingsFluent.DefaultNetworkSettingsNested<N>>{

        
    public N and();    public N endDefaultNetworkSettings();
}
    public interface NetworkSettingsBaseNested<N> extends io.fabric8.docker.api.builder.Nested<N>,NetworkSettingsBaseFluent<NetworkSettingsFluent.NetworkSettingsBaseNested<N>>{

        
    public N and();    public N endNetworkSettingsBase();
}


}

==> docker-model-1.2.2-sources.jar: annotations/io/fabric8/docker/api/model/NetworkSettingsFluent.java <==
package io.fabric8.docker.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.docker.api.builder.Fluent;
import io.fabric8.docker.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface NetworkSettingsFluent<A extends NetworkSettingsFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildDefaultNetworkSettings instead.
 */
@Deprecated public DefaultNetworkSettings getDefaultNetworkSettings();
    public DefaultNetworkSettings buildDefaultNetworkSettings();
    public A withDefaultNetworkSettings(DefaultNetworkSettings DefaultNetworkSettings);
    public Boolean hasDefaultNetworkSettings();
    public NetworkSettingsFluent.DefaultNetworkSettingsNested<A> withNewDefaultNetworkSettings();
    public NetworkSettingsFluent.DefaultNetworkSettingsNested<A> withNewDefaultNetworkSettingsLike(DefaultNetworkSettings item);
    public NetworkSettingsFluent.DefaultNetworkSettingsNested<A> editDefaultNetworkSettings();
    public NetworkSettingsFluent.DefaultNetworkSettingsNested<A> editOrNewDefaultNetworkSettings();
    public NetworkSettingsFluent.DefaultNetworkSettingsNested<A> editOrNewDefaultNetworkSettingsLike(DefaultNetworkSettings item);
    
/**
 * This method has been deprecated, please use method buildNetworkSettingsBase instead.
 */
@Deprecated public NetworkSettingsBase getNetworkSettingsBase();
    public NetworkSettingsBase buildNetworkSettingsBase();
    public A withNetworkSettingsBase(NetworkSettingsBase NetworkSettingsBase);
    public Boolean hasNetworkSettingsBase();
    public NetworkSettingsFluent.NetworkSettingsBaseNested<A> withNewNetworkSettingsBase();
    public NetworkSettingsFluent.NetworkSettingsBaseNested<A> withNewNetworkSettingsBaseLike(NetworkSettingsBase item);
    public NetworkSettingsFluent.NetworkSettingsBaseNested<A> editNetworkSettingsBase();
    public NetworkSettingsFluent.NetworkSettingsBaseNested<A> editOrNewNetworkSettingsBase();
    public NetworkSettingsFluent.NetworkSettingsBaseNested<A> editOrNewNetworkSettingsBaseLike(NetworkSettingsBase item);
    public A addToNetworks(String key,EndpointSettings value);
    public A addToNetworks(Map<String,EndpointSettings> map);
    public A removeFromNetworks(String key);
    public A removeFromNetworks(Map<String,EndpointSettings> map);
    public Map<String,EndpointSettings> getNetworks();
    public A withNetworks(Map<String,EndpointSettings> Networks);
    public Boolean hasNetworks();

    public interface DefaultNetworkSettingsNested<N> extends io.fabric8.docker.api.builder.Nested<N>,DefaultNetworkSettingsFluent<NetworkSettingsFluent.DefaultNetworkSettingsNested<N>>{

        
    public N and();    public N endDefaultNetworkSettings();
}
    public interface NetworkSettingsBaseNested<N> extends io.fabric8.docker.api.builder.Nested<N>,NetworkSettingsBaseFluent<NetworkSettingsFluent.NetworkSettingsBaseNested<N>>{

        
    public N and();    public N endNetworkSettingsBase();
}


}
